@@ -6,10 +6,15 @@
 #' @param saga_cmd The path of the saga_cmd binary.
 #'
 #' @return A numeric_version with the version of SAGA-GIS found at the cmd path.
+#' 
+#' @export
 saga_version <- function(saga_cmd) {
   
   saga_vers <- system(paste(shQuote(saga_cmd), "--version"), intern = T)[1]
-  saga_vers <- regmatches(saga_vers, regexpr("\\d.\\d.\\d", saga_vers))
+  saga_vers <- regmatches(
+    x = saga_vers, 
+    m = regexpr("[[:digit:]]?[.][[:digit:]]{1,2}[.][[:digit:]]", saga_vers)
+  )
   saga_vers <- trimws(saga_vers)
   
   as.numeric_version(saga_vers)
